# B

Yes.

![Caption Text Red](images/red.png "Alt Text Red")

![Caption Text Dot Dot Lime](../images/lime.png "Alt Text Dot Dot Lime")

Yes, an SVG file:

![Caption Text for SVG](diagrams/squares-and-edges.svg "Alt Text for SVG")

And another one with application hinting suffices:

![Caption Text for app specific SVG](diagrams/nuts-and-bolts.app.svg "Alt Text for app specific SVG")

**Some bold text** normal text _italic text_ - even _**bold italic**_ and so ***123*** on.

Enumerated list:

1. wun
1. two
1. three

